@@ -2,7 +2,7 @@ package Archive::Peek::Libarchive;
 use strict;
 use warnings;
 use Object::Tiny qw{ filename };
-our $VERSION = '0.36';
+our $VERSION = '0.37';
 
 require XSLoader;
 XSLoader::load( 'Archive::Peek::Libarchive', $VERSION );
@@ -22,6 +22,12 @@ sub file {
     return $file;
 }
 
+sub iterate {
+    my ( $self, $callback ) = @_;
+    my $filename = $self->filename;
+    Archive::Peek::Libarchive::_iterate( $filename, $callback );
+}
+
 1;
 
 __END__
@@ -37,6 +43,13 @@ Archive::Peek::Libarchive - Peek into archives without extracting them (using li
   my @files = $peek->files();
   my $contents = $peek->file('README.txt')
 
+  $peek->iterate(
+    sub {
+      my ( $filename, $contents ) = @_;
+      ...
+    }
+  );
+
 =head1 DESCRIPTION
 
 This module lets you peek into archives without extracting them. This is
@@ -65,6 +78,17 @@ Returns the contents of a file in the archive:
 
   my $contents = $peek->file('README.txt')
 
+=head2 iterate
+
+Iterate over all the files in the archive:
+
+  $peek->iterate(
+    sub {
+      my ( $filename, $contents ) = @_;
+      ...
+    }
+  );
+
 =head1 AUTHOR
 
 Leon Brocard <acme@astray.com>
